.. image:: https://img.shields.io/travis/r3w0p/bobocep/master.svg
   :target: https://travis-ci.org/r3w0p/bobocep
   :alt: Travis CI

.. image:: https://coveralls.io/repos/github/r3w0p/bobocep/badge.svg?branch=master
   :target: https://coveralls.io/github/r3w0p/bobocep?branch=master
   :alt: Coveralls

.. image:: https://img.shields.io/lgtm/alerts/g/r3w0p/bobocep.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/r3w0p/bobocep/alerts
   :alt: LGTM Alerts

.. image:: https://img.shields.io/lgtm/grade/python/github/r3w0p/bobocep
   :target: https://lgtm.com/projects/g/r3w0p/bobocep/context:python
   :alt: LGTM Code Quality

.. image:: https://img.shields.io/github/last-commit/r3w0p/bobocep
   :target: https://github.com/r3w0p/bobocep/graphs/commit-activity
   :alt: Last Commit

|

.. image:: https://img.shields.io/pypi/v/bobocep
   :target: https://pypi.org/project/bobocep
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/bobocep
   :target: https://pypi.org/project/bobocep
   :alt: Python Versions

.. image:: https://img.shields.io/github/license/r3w0p/bobocep
   :target: https://github.com/r3w0p/bobocep/blob/master/LICENSE
   :alt: License

.. image:: https://img.shields.io/badge/docs-pages-informational
   :target: https://r3w0p.github.io/bobocep
   :alt: Documentation

.. image:: https://img.shields.io/badge/code-github-24292e
   :target: https://github.com/r3w0p/bobocep
   :alt: GitHub Repository

.. image:: https://img.shields.io/badge/donate-buy%20me%20a%20coffee-orange.svg
   :target: https://www.buymeacoffee.com/r3w0p
   :alt: Buy Me A Coffee

|

:code:`bobocep` is a `complex event processing <https://en.wikipedia.org/wiki/Complex_event_processing>`_ (CEP) engine
designed for `edge computing <https://en.wikipedia.org/wiki/Edge_computing>`_ in
`Internet of Things <https://en.wikipedia.org/wiki/Internet_of_things>`_ (IoT) systems
to provide inferential reasoning and decision making using stream data.
It provides `fault tolerance <https://en.wikipedia.org/wiki/Fault_tolerance>`_ (FT) via the
`active replication <https://en.wikipedia.org/wiki/Replication_(computing)>`_ of
partially-completed complex events across multiple instances of the software using a
`message broker <https://en.wikipedia.org/wiki/Message_broker>`_.

This is **experimental** software that is currently being used for research purposes.
All aspects of the software are subject to change.
